@@ -7,29 +7,26 @@ use warnings;
 
 use CLI::Helpers qw(:output);
 use Data::Printer;
-use FindBin;
 use Hash::Flatten qw(flatten);
+use JSON::MaybeXS;
 use Getopt::Long::Descriptive;
-use Path::Tiny;
 use YAML;
 
 use eris::log::contextualizer;
 use eris::schemas;
 
-#------------------------------------------------------------------------#
-# Path Setup
-my $path_base = path("$FindBin::Bin")->parent;
-
 #------------------------------------------------------------------------#
 # Argument Parsing
 my ($opt,$usage) = describe_options(
     "%c %o ",
-    [ 'sample|s:s', "Sample messages from the specified context" ],
+    [ 'sample|s=s', "Sample messages from the specified context" ],
+    ['schema|filtered|f', "Show the schema fitlered output from the schema match instead." ],
     ['bulk|b',      "Show the bulk output from the schema match instead." ],
+    ['json|j',      "Show the structure are JSON." ],
     ['flatten|F',   "Flatten the hash keys, defaults to false."],
     ['complete|C',  "Use the complete object instead of just the uniqued context."],
     [],
-    [ 'config|c:s', "eris config file", {
+    [ 'config|c=s', "eris config file", {
         callbacks => { exists => sub { -f shift } }
     }],
     [ 'help' => 'Display this message and exit', { shortcircuit => 1 } ],
@@ -70,14 +67,19 @@ else {
 sub dump_record {
     my $msg = shift;
     my $l = $ctxr->parse($msg);
+    my $v = $opt->schema ? $schm->to_document($l)
+          : $l->as_doc(
+                $opt->flatten  ? ( flatten => 1 )  : (),
+                $opt->complete ? ( complete => 1 ) : (),
+            );
     if( $opt->bulk ) {
         output({data=>1}, $schm->as_bulk($l));
     }
+    elsif( $opt->json ) {
+        output({data=>1}, encode_json($v));
+    }
     else {
-        p($l->as_doc(
-            $opt->flatten  ? ( flatten => 1 )  : (),
-            $opt->complete ? ( complete => 1 ) : (),
-        ));
+        p($v);
     }
 }
 
@@ -93,7 +95,7 @@ eris-context.pl - Utility for testing the logging contextualizer
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 AUTHOR
 
