@@ -8,7 +8,7 @@ with qw(
 );
 use namespace::autoclean;
 
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 
 sub sample_messages {
@@ -29,18 +29,16 @@ const my %MAP => (
 
 sub contextualize_message {
     my ($self,$log) = @_;
-    my $str = $log->context->{message};
+    my $c = $log->context;
+    my $sdata = $c->{sdata};
+    my $str   = $c->{message};
 
     my %ctxt = ();
 
     my ($user,$variables) = split ' : ', $str, 2;
-    if( defined $variables ) {
-        chomp($variables);
-        foreach my $pair (split ' ; ', $variables) {
-            my ($k,$v) = split '=', $pair;
-            if(exists $MAP{$k}) {
-                $ctxt{$MAP{$k}} = $v;
-            }
+    foreach my $k (sort keys %MAP) {
+        if( exists $sdata->{$k} ) {
+            $ctxt{$MAP{$k}} = $sdata->{$k};
         }
     }
     if( exists $ctxt{exe} ) {
@@ -67,7 +65,7 @@ eris::log::context::sudo - Parses the sudo key=value pairs into structured docum
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 SYNOPSIS
 
